@@ -6,8 +6,8 @@
 
 #pragma once
 
-#include <collection.h>
-#include <item.h>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
 namespace Helper
 {
