@@ -7,13 +7,13 @@
 #include "historytest.h"
 #include "helper.h"
 
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/CollectionFetchScope>
+#include <Akonadi/ItemCreateJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 #include <KCalendarCore/Event>
-#include <collectionfetchjob.h>
-#include <collectionfetchscope.h>
-#include <itemcreatejob.h>
-#include <itemfetchjob.h>
-#include <itemfetchscope.h>
-#include <qtest_akonadi.h>
+#include <akonadi/qtest_akonadi.h>
 
 #include <QTestEventLoop>
 
@@ -392,7 +392,7 @@ void HistoryTest::testMix_data()
     items << i << i << i;
     changeTypes.clear();
     changeTypes << IncidenceChanger::ChangeTypeCreate << IncidenceChanger::ChangeTypeModify << IncidenceChanger::ChangeTypeDelete;
-    QTest::newRow("create then modify then deelte") << items << changeTypes;
+    QTest::newRow("create then modify then delete") << items << changeTypes;
 }
 
 void HistoryTest::testMix()
