@@ -4,12 +4,11 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef UNITTEST_BASE_H
-#define UNITTEST_BASE_H
+#pragma once
 
-#include <collection.h>
-#include <item.h>
-#include <kcalendarcore/calendar.h>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
+#include <KCalendarCore/Calendar>
 
 #include <QObject>
 #include <QString>
@@ -44,4 +43,3 @@ protected:
     Akonadi::IncidenceChanger *mChanger = nullptr;
 };
 
-#endif
