@@ -6,9 +6,9 @@
 
 #include "akonadi_serializer_kcalcore.h"
 
-#include <AkonadiCore/AbstractDifferencesReporter>
-#include <AkonadiCore/Collection>
-#include <AkonadiCore/Item>
+#include <Akonadi/AbstractDifferencesReporter>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
 #include <KCalendarCore/Event>
 #include <KCalendarCore/Todo>
@@ -155,7 +155,7 @@ static QString toString(const Attachment &)
     return QString();
 }
 
-static QString toString(const QDate &date)
+static QString toString(QDate date)
 {
     return date.toString();
 }
