@@ -10,7 +10,7 @@
 #include "calendarbase_p.h"
 #include "incidencechanger.h"
 #include "utils_p.h"
-#include <collectionfetchjob.h>
+#include <Akonadi/CollectionFetchJob>
 
 #include <KLocalizedString>
 #include <QTimeZone>
@@ -50,7 +50,6 @@ CalendarBasePrivate::CalendarBasePrivate(CalendarBase *qq)
 CalendarBasePrivate::~CalendarBasePrivate()
 {
     delete mIncidenceChanger;
-    mIncidenceChanger = nullptr;
 }
 
 void CalendarBasePrivate::internalInsert(const Akonadi::Item &item)
@@ -475,7 +474,7 @@ Akonadi::Item::List CalendarBase::itemList(const KCalendarCore::Incidence::List
 KCalendarCore::Incidence::List CalendarBase::childIncidences(Akonadi::Item::Id parentId) const
 {
     Q_D(const CalendarBase);
-    KCalendarCore::Incidence::List childs;
+    KCalendarCore::Incidence::List children;
 
     if (d->mItemById.contains(parentId)) {
         const Akonadi::Item item = d->mItemById.value(parentId);
@@ -483,13 +482,13 @@ KCalendarCore::Incidence::List CalendarBase::childIncidences(Akonadi::Item::Id p
         KCalendarCore::Incidence::Ptr parent = CalendarUtils::incidence(item);
 
         if (parent) {
-            childs = childIncidences(parent->uid());
+            children = childIncidences(parent->uid());
         } else {
             Q_ASSERT(false);
         }
     }
 
-    return childs;
+    return children;
 }
 
 KCalendarCore::Incidence::List CalendarBase::childIncidences(const QString &parentUid) const
@@ -511,7 +510,7 @@ KCalendarCore::Incidence::List CalendarBase::childIncidences(const QString &pare
 Akonadi::Item::List CalendarBase::childItems(Akonadi::Item::Id parentId) const
 {
     Q_D(const CalendarBase);
-    Akonadi::Item::List childs;
+    Akonadi::Item::List children;
 
     if (d->mItemById.contains(parentId)) {
         const Akonadi::Item item = d->mItemById.value(parentId);
@@ -519,13 +518,13 @@ Akonadi::Item::List CalendarBase::childItems(Akonadi::Item::Id parentId) const
         KCalendarCore::Incidence::Ptr parent = CalendarUtils::incidence(item);
 
         if (parent) {
-            childs = childItems(parent->uid());
+            children = childItems(parent->uid());
         } else {
             Q_ASSERT(false);
         }
     }
 
-    return childs;
+    return children;
 }
 
 Akonadi::Item::List CalendarBase::childItems(const QString &parentUid) const
