@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CALENDARBASE_P_H
-#define AKONADI_CALENDARBASE_P_H
+#pragma once
 
 #include "calendarbase.h"
 #include "incidencechanger.h"
@@ -20,7 +19,7 @@ class CalendarBasePrivate : public QObject
     Q_OBJECT
 public:
     explicit CalendarBasePrivate(CalendarBase *qq);
-    ~CalendarBasePrivate();
+    ~CalendarBasePrivate() override;
 
     void internalInsert(const Akonadi::Item &item);
     void internalRemove(const Akonadi::Item &item);
@@ -50,7 +49,7 @@ public:
     QHash<KJob *, Akonadi::Collection::Id> mCollectionJobs;
     QHash<QString, Akonadi::Item::Id> mItemIdByUid;
     QHash<Akonadi::Item::Id, Akonadi::Item> mItemById;
-    Akonadi::IncidenceChanger *mIncidenceChanger = nullptr;
+    Akonadi::IncidenceChanger *const mIncidenceChanger;
     QHash<QString, QStringList> mParentUidToChildrenUid;
     Akonadi::Collection mCollectionForBatchInsertion;
     bool mBatchInsertionCancelled = false;
@@ -68,4 +67,3 @@ private:
 };
 }
 
-#endif
