@@ -12,9 +12,12 @@
 #include <KCalendarCore/Incidence>
 #include <QObject>
 
+#include <memory>
+
 namespace Akonadi
 {
 class IncidenceChanger;
+class CalendarClipboardPrivate;
 
 /**
  * @short Class to copy or cut calendar incidences.
@@ -43,7 +46,7 @@ public:
     /**
      * Destroys the CalendarClipboard instance.
      */
-    ~CalendarClipboard();
+    ~CalendarClipboard() override;
 
     /**
      * Copies the specified incidence into the clipboard and then deletes it from akonadi.
@@ -77,8 +80,7 @@ Q_SIGNALS:
     void cutFinished(bool success, const QString &errorMessage);
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<CalendarClipboardPrivate> const d;
 };
 }
 
