@@ -9,11 +9,11 @@
 #include "calendarmodel_p.h"
 
 #include "utils_p.h"
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/Monitor>
 #include <KCalendarCore/Event>
 #include <KCalendarCore/Journal>
-#include <itemfetchscope.h>
-#include <kcalendarcore/todo.h>
-#include <monitor.h>
+#include <KCalendarCore/Todo>
 
 #include <KLocalizedString>
 
@@ -26,10 +26,10 @@ static KCalendarCore::Todo::Ptr todo(const Akonadi::Item &item)
     return item.hasPayload<KCalendarCore::Todo::Ptr>() ? item.payload<KCalendarCore::Todo::Ptr>() : KCalendarCore::Todo::Ptr();
 }
 
-class Q_DECL_HIDDEN CalendarModel::Private
+class Akonadi::CalendarModelPrivate
 {
 public:
-    Private()
+    CalendarModelPrivate()
     {
     }
 
@@ -38,7 +38,7 @@ public:
 
 CalendarModel::CalendarModel(Akonadi::Monitor *monitor)
     : EntityTreeModel(monitor)
-    , d(new Private())
+    , d(new CalendarModelPrivate())
 {
     monitor->itemFetchScope().fetchAllAttributes(true);
 }
@@ -51,10 +51,7 @@ CalendarModel::Ptr CalendarModel::create(Monitor *monitor)
     return modelPtr;
 }
 
-CalendarModel::~CalendarModel()
-{
-    delete d;
-}
+CalendarModel::~CalendarModel() = default;
 
 QWeakPointer<CalendarModel> CalendarModel::weakPointer() const
 {
@@ -74,19 +71,20 @@ QVariant CalendarModel::entityData(const Akonadi::Item &item, int column, int ro
     }
 
     switch (role) {
-    case Qt::DecorationRole:
+    case Qt::DecorationRole: {
         if (column != Summary) {
             return QVariant();
         }
-        if (inc->type() == KCalendarCore::IncidenceBase::TypeTodo) {
+        const auto incType{inc->type()};
+        if (incType == KCalendarCore::IncidenceBase::TypeTodo) {
             return QIcon::fromTheme(QStringLiteral("view-pim-tasks"));
-        } else if (inc->type() == KCalendarCore::IncidenceBase::TypeJournal) {
+        } else if (incType == KCalendarCore::IncidenceBase::TypeJournal) {
             return QIcon::fromTheme(QStringLiteral("view-pim-journal"));
-        } else if (inc->type() == KCalendarCore::IncidenceBase::TypeEvent) {
+        } else if (incType == KCalendarCore::IncidenceBase::TypeEvent) {
             return QIcon::fromTheme(QStringLiteral("view-calendar"));
         }
         return QIcon::fromTheme(QStringLiteral("network-wired"));
-
+    }
     case Qt::DisplayRole:
         switch (column) {
         case Summary:
