@@ -7,13 +7,17 @@
 
 #pragma once
 
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/Monitor>
 #include <QSharedPointer>
 #include <QWeakPointer>
-#include <entitytreemodel.h>
-#include <monitor.h>
+
+#include <memory>
 
 namespace Akonadi
 {
+class CalendarModelPrivate;
+
 class CalendarModel : public Akonadi::EntityTreeModel
 {
     Q_OBJECT
@@ -41,8 +45,8 @@ public:
 
 private:
     explicit CalendarModel(Akonadi::Monitor *monitor);
-    class Private;
-    Private *const d;
+
+    std::unique_ptr<CalendarModelPrivate> const d;
 };
 }
 
