@@ -7,22 +7,21 @@
 #include "calfilterpartstatusproxymodel_p.h"
 #include "utils_p.h"
 
-#include <collection.h>
-#include <entitytreemodel.h>
-#include <item.h>
+#include <Akonadi/Collection>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/Item>
 
 #include <KCalendarCore/Incidence>
 // #include <email.h>
 
-#include <KEMailSettings>
 #include <identitymanager.h>
 
 using namespace Akonadi;
 
-class Q_DECL_HIDDEN CalFilterPartStatusProxyModel::Private
+class Akonadi::CalFilterPartStatusProxyModelPrivate
 {
 public:
-    explicit Private()
+    explicit CalFilterPartStatusProxyModelPrivate()
         : mIdentityManager(KIdentityManagement::IdentityManager::self())
     {
     }
@@ -39,18 +38,15 @@ void CalFilterPartStatusProxyModel::slotIdentitiesChanged()
 
 CalFilterPartStatusProxyModel::CalFilterPartStatusProxyModel(QObject *parent)
     : QSortFilterProxyModel(parent)
-    , d(new Private())
+    , d(new CalFilterPartStatusProxyModelPrivate())
 {
     QObject::connect(d->mIdentityManager,
-                     QOverload<>::of(&KIdentityManagement::IdentityManager::changed),
+                     qOverload<>(&KIdentityManagement::IdentityManager::changed),
                      this,
                      &CalFilterPartStatusProxyModel::slotIdentitiesChanged);
 }
 
-CalFilterPartStatusProxyModel::~CalFilterPartStatusProxyModel()
-{
-    delete d;
-}
+CalFilterPartStatusProxyModel::~CalFilterPartStatusProxyModel() = default;
 
 const QList<KCalendarCore::Attendee::PartStat> &CalFilterPartStatusProxyModel::blockedStatusList() const
 {
