@@ -8,18 +8,18 @@
 #include "calfilterproxymodel_p.h"
 #include "utils_p.h"
 
-#include <entitytreemodel.h>
-#include <item.h>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/Item>
 
 #include <KCalendarCore/CalFilter>
 #include <KCalendarCore/Incidence>
 
 using namespace Akonadi;
 
-class Q_DECL_HIDDEN CalFilterProxyModel::Private
+class Akonadi::CalFilterProxyModelPrivate
 {
 public:
-    explicit Private()
+    explicit CalFilterProxyModelPrivate()
     {
     }
 
@@ -28,15 +28,12 @@ public:
 
 CalFilterProxyModel::CalFilterProxyModel(QObject *parent)
     : QSortFilterProxyModel(parent)
-    , d(new Private)
+    , d(new CalFilterProxyModelPrivate)
 {
     setFilterKeyColumn(0);
 }
 
-CalFilterProxyModel::~CalFilterProxyModel()
-{
-    delete d;
-}
+CalFilterProxyModel::~CalFilterProxyModel() = default;
 
 KCalendarCore::CalFilter *CalFilterProxyModel::filter() const
 {
@@ -64,7 +61,7 @@ bool CalFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex &so
         return false;
     }
 
-    const Akonadi::Item item = idx.data(Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+    const auto item = idx.data(Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
     if (!item.isValid()) {
         return false;
     }
