@@ -9,6 +9,8 @@
 
 #include <QSortFilterProxyModel>
 
+#include <memory>
+
 namespace KCalendarCore
 {
 class CalFilter;
@@ -16,6 +18,8 @@ class CalFilter;
 
 namespace Akonadi
 {
+class CalFilterProxyModelPrivate;
+
 class CalFilterProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
@@ -30,8 +34,7 @@ protected:
     bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<CalFilterProxyModelPrivate> const d;
 };
 }
 
