@@ -11,8 +11,8 @@
 #include "etmcalendar.h"
 #include "incidencechanger.h"
 
+#include <Akonadi/EntityTreeModel>
 #include <KCheckableProxyModel>
-#include <entitytreemodel.h>
 
 #include <QModelIndex>
 #include <QSet>
@@ -70,7 +70,7 @@ class ETMCalendarPrivate : public CalendarBasePrivate
     Q_OBJECT
 public:
     explicit ETMCalendarPrivate(ETMCalendar *qq);
-    ~ETMCalendarPrivate();
+    ~ETMCalendarPrivate() override;
 
     void init();
     void setupFilteredETM();
