@@ -13,6 +13,9 @@
 #include "etmcalendar.h"
 
 #include <KCalendarCore/FreeBusyCache>
+
+#include <memory>
+
 // TODO: document
 namespace Akonadi
 {
@@ -50,7 +53,7 @@ public:
       to download our own freebusy information.
 
       This method will first try to find Akonadi resource that have the
-      'FreeBusyProvider' capablity set. If none is found then there is a fallback
+      'FreeBusyProvider' capability set. If none is found then there is a fallback
       on the URL mechanism (see below). If at least one is found then it will
       be first queried over D-Bus to know if it can handle free-busy information
       for that email address. If true then it will be queried for the free-busy
@@ -133,7 +136,7 @@ private:
 private:
     friend class FreeBusyManagerStatic;
 
-    FreeBusyManagerPrivate *const d_ptr;
+    std::unique_ptr<FreeBusyManagerPrivate> const d_ptr;
     Q_DECLARE_PRIVATE(FreeBusyManager)
     Q_DISABLE_COPY(FreeBusyManager)
     Q_PRIVATE_SLOT(d_ptr, void checkFreeBusyUrl())
