@@ -9,15 +9,18 @@
 #include "akonadi-calendar_export.h"
 #include "incidencechanger.h"
 
+#include <Akonadi/Item>
 #include <KCalendarCore/Incidence>
 #include <QWidget>
-#include <item.h>
+
+#include <memory>
 
 class HistoryTest;
 
 namespace Akonadi
 {
 class IncidenceChanger;
+class HistoryPrivate;
 
 /**
    @short History class for implementing undo/redo of calendar operations
@@ -60,7 +63,7 @@ public:
     /**
      * Destroys the History instance.
      */
-    ~History();
+    ~History() override;
 
     /**
      * Pushes an incidence creation onto the undo stack. The creation can be
@@ -227,6 +230,7 @@ Q_SIGNALS:
 private:
     friend class ::HistoryTest;
     friend class IncidenceChanger;
+    friend class IncidenceChangerPrivate;
     friend class Entry;
 
     // Only IncidenceChanger can create History classes
@@ -235,9 +239,9 @@ private:
     // Used by unit-tests
     Akonadi::IncidenceChanger *incidenceChanger() const;
 
+private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<HistoryPrivate> const d;
     //@endcond
 };
 }
