@@ -10,11 +10,13 @@
 
 #include "akonadi-calendar_export.h"
 
-#include <collection.h>
+#include <Akonadi/Collection>
 
 #include <QObject>
 #include <QString>
 
+#include <memory>
+
 /**
  * A class to import ical calendar files into akonadi.
  *
@@ -23,6 +25,7 @@
 namespace Akonadi
 {
 class IncidenceChanger;
+class ICalImporterPrivate;
 
 class AKONADI_CALENDAR_EXPORT ICalImporter : public QObject
 {
@@ -36,7 +39,7 @@ public:
      * @param parent  Parent QObject.
      */
     explicit ICalImporter(Akonadi::IncidenceChanger *changer = nullptr, QObject *parent = nullptr);
-    ~ICalImporter();
+    ~ICalImporter() override;
 
     /**
      * Translated error message.
@@ -80,11 +83,10 @@ public Q_SLOTS:
      *
      *         true if the import job was started. importIntoExistingFinished() signal will be emitted in this case.
      */
-    bool importIntoExistingResource(const QUrl &url, Collection collection);
+    bool importIntoExistingResource(const QUrl &url, Akonadi::Collection collection);
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<ICalImporterPrivate> const d;
 };
 }
 
