@@ -7,10 +7,10 @@
 
 #pragma once
 
+#include <Akonadi/Item>
+#include <Akonadi/Job>
+#include <Akonadi/MimeTypeChecker>
 #include <KCalendarCore/Incidence>
-#include <item.h>
-#include <job.h>
-#include <mimetypechecker.h>
 
 namespace Akonadi
 {
