@@ -10,8 +10,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CALENDAR_ITIP_HANDLER_H
-#define AKONADI_CALENDAR_ITIP_HANDLER_H
+#pragma once
 
 #include "akonadi-calendar_export.h"
 #include "etmcalendar.h"
@@ -26,6 +25,8 @@
 #include <QString>
 #include <QWidget>
 
+#include <memory>
+
 namespace MailTransport
 {
 class MessageQueueJob;
@@ -38,6 +39,8 @@ class Identity;
 
 namespace Akonadi
 {
+class ITIPHandlerPrivate;
+
 /**
  * @short Ui delegate for editing counter proposals.
  * @since 4.11
@@ -64,12 +67,12 @@ class AKONADI_CALENDAR_EXPORT ITIPHandlerDialogDelegate : public QObject
 public:
     // Possible default actions
     enum Action {
-        ActionAsk, /**< Ask the user for a descision */
+        ActionAsk, /**< Ask the user for a decision */
         ActionSendMessage, /**< Answer with Yes */
         ActionDontSendMessage /**< Answer with No */
     };
 
-    // How will reveive the mail afterwards
+    // How will receive the mail afterwards
     enum Recipient {
         Organizer, /**< the organizer of the incidence */
         Attendees /**< the attendees of the incidence */
@@ -215,7 +218,7 @@ public:
 };
 
 /**
- * @short Handles sending of iTip messages aswell as processing incoming ones.
+ * @short Handles sending of iTip messages as well as processing incoming ones.
  * @since 4.11
  */
 class AKONADI_CALENDAR_EXPORT ITIPHandler : public QObject
@@ -224,7 +227,7 @@ class AKONADI_CALENDAR_EXPORT ITIPHandler : public QObject
 public:
     enum Result {
         ResultError, /**< An unexpected error occurred */
-        ResultSuccess, /**< The invitation was successfuly handled. */
+        ResultSuccess, /**< The invitation was successfully handled. */
         ResultCancelled /**< User cancelled the operation. @since 4.12 */
     };
 
@@ -243,7 +246,7 @@ public:
     /**
      * Destroys this instance.
      */
-    ~ITIPHandler();
+    ~ITIPHandler() override;
 
     /**
      * Processes a received iTip message.
@@ -312,7 +315,7 @@ Q_SIGNALS:
      *
      * @param result success of the operation.
      * @param errorMessage translated error message suitable for user dialogs.
-     *                     Empty if the operation was successul
+     *                     Empty if the operation was successful
      */
     void iTipMessageProcessed(Akonadi::ITIPHandler::Result result, const QString &errorMessage);
 
@@ -333,9 +336,7 @@ Q_SIGNALS:
 
 private:
     Q_DISABLE_COPY(ITIPHandler)
-    class Private;
-    Private *const d;
+    std::unique_ptr<ITIPHandlerPrivate> const d;
 };
 }
 
-#endif
