@@ -11,8 +11,8 @@
 #include "akonadi-calendar_tests_export.h"
 #include "itiphandler.h"
 #include <KCalendarCore/IncidenceBase>
+#include <KMime/KMimeMessage>
 #include <QObject>
-#include <kmime/kmime_message.h>
 
 struct UnitTestResult {
     using List = QVector<UnitTestResult>;
@@ -46,7 +46,7 @@ public:
     enum Result { ResultSuccess, ResultNoAttendees, ResultReallyNoAttendees, ResultErrorCreatingTransport, ResultErrorFetchingTransport, ResultQueueJobError };
 
     explicit MailClient(ITIPHandlerComponentFactory *factory, QObject *parent = nullptr);
-    ~MailClient();
+    ~MailClient() override;
 
     void mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidence,
                        const KIdentityManagement::Identity &identity,
