@@ -10,10 +10,14 @@
 #include <KCalendarCore/Attendee>
 #include <QDialog>
 
+#include <memory>
+
 // TODO: documentation
 // Uses akonadi-contact, so don't move this class to KCalUtils.
 namespace Akonadi
 {
+class PublishDialogPrivate;
+
 class AKONADI_CALENDAR_EXPORT PublishDialog : public QDialog
 {
     Q_OBJECT
@@ -47,8 +51,7 @@ public Q_SLOTS:
 private:
     void slotHelp();
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<PublishDialogPrivate> const d;
     //@endcond
 };
 }
