@@ -6,7 +6,6 @@
 */
 
 #include "publishdialog_p.h"
-
 #include <Akonadi/Contact/AbstractEmailAddressSelectionDialog>
 #include <Akonadi/Contact/EmailAddressSelectionDialog>
 #include <KCalendarCore/Person>
@@ -14,20 +13,19 @@
 
 #include <KLocalizedString>
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <QPointer>
 #include <QTreeView>
 
 using namespace KCalendarCore;
 using namespace Akonadi;
 
-PublishDialog::Private::Private(PublishDialog *qq)
+PublishDialogPrivate::PublishDialogPrivate(PublishDialog *qq)
     : QObject()
     , q(qq)
 {
 }
 
-void PublishDialog::Private::addItem()
+void PublishDialogPrivate::addItem()
 {
     mUI.mNameLineEdit->setEnabled(true);
     mUI.mEmailLineEdit->setEnabled(true);
@@ -49,7 +47,7 @@ void PublishDialog::Private::addItem()
     mUI.mRemove->setEnabled(true);
 }
 
-void PublishDialog::Private::removeItem()
+void PublishDialogPrivate::removeItem()
 {
     if (mUI.mListWidget->selectedItems().isEmpty()) {
         return;
@@ -74,7 +72,7 @@ void PublishDialog::Private::removeItem()
     mUI.mListWidget->setCurrentRow(row);
 }
 
-void PublishDialog::Private::insertAddresses(const KContacts::Addressee::List &list)
+void PublishDialogPrivate::insertAddresses(const KContacts::Addressee::List &list)
 {
     for (const KContacts::Addressee &contact : list) {
         mUI.mNameLineEdit->setEnabled(true);
@@ -87,19 +85,21 @@ void PublishDialog::Private::insertAddresses(const KContacts::Addressee::List &l
     }
 }
 
-void PublishDialog::Private::openAddressbook()
+void PublishDialogPrivate::openAddressbook()
 {
     QPointer<Akonadi::AbstractEmailAddressSelectionDialog> dialog;
-    KPluginLoader loader(QStringLiteral("akonadi/emailaddressselectionldapdialogplugin"));
-    KPluginFactory *factory = loader.factory();
-    if (factory) {
-        dialog = factory->create<Akonadi::AbstractEmailAddressSelectionDialog>(q);
+
+    const KPluginMetaData editWidgetPlugin(QStringLiteral("akonadi/emailaddressselectionldapdialogplugin"));
+
+    const auto result = KPluginFactory::instantiatePlugin<Akonadi::AbstractEmailAddressSelectionDialog>(editWidgetPlugin, q);
+    if (result) {
+        dialog = result.plugin;
     } else {
         dialog = new Akonadi::EmailAddressSelectionDialog(q);
     }
 
     dialog->view()->view()->setSelectionMode(QAbstractItemView::MultiSelection);
-    connect(dialog.data(), &Akonadi::AbstractEmailAddressSelectionDialog::insertAddresses, this, &PublishDialog::Private::insertAddresses);
+    connect(dialog.data(), &Akonadi::AbstractEmailAddressSelectionDialog::insertAddresses, this, &PublishDialogPrivate::insertAddresses);
     if (dialog->exec() == QDialog::Accepted) {
         const Akonadi::EmailAddressSelection::List selections = dialog->selectedAddresses();
         if (!selections.isEmpty()) {
@@ -119,7 +119,7 @@ void PublishDialog::Private::openAddressbook()
     delete dialog;
 }
 
-void PublishDialog::Private::updateItem()
+void PublishDialogPrivate::updateItem()
 {
     if (mUI.mListWidget->selectedItems().isEmpty()) {
         return;
@@ -130,7 +130,7 @@ void PublishDialog::Private::updateItem()
     item->setText(person.fullName());
 }
 
-void PublishDialog::Private::updateInput()
+void PublishDialogPrivate::updateInput()
 {
     if (mUI.mListWidget->selectedItems().isEmpty()) {
         return;
@@ -140,7 +140,8 @@ void PublishDialog::Private::updateInput()
     mUI.mEmailLineEdit->setEnabled(true);
 
     QListWidgetItem *item = mUI.mListWidget->selectedItems().at(0);
-    QString mail, name;
+    QString mail;
+    QString name;
     KEmailAddress::extractEmailAddressAndName(item->text(), mail, name);
     mUI.mNameLineEdit->setText(name);
     mUI.mEmailLineEdit->setText(mail);
