@@ -21,9 +21,10 @@
 using namespace KCalendarCore;
 using namespace Akonadi;
 
-struct Akonadi::Scheduler::Private {
+class Akonadi::SchedulerPrivate
+{
 public:
-    Private(Scheduler *qq)
+    explicit SchedulerPrivate(Scheduler *qq)
         : q(qq)
     {
     }
@@ -35,7 +36,7 @@ public:
 
 Scheduler::Scheduler(QObject *parent)
     : QObject(parent)
-    , d(new Akonadi::Scheduler::Private(this))
+    , d(new SchedulerPrivate(this))
 {
     mFormat = new ICalFormat();
     mFormat->setTimeZone(QTimeZone::systemTimeZone());
@@ -44,7 +45,6 @@ Scheduler::Scheduler(QObject *parent)
 Scheduler::~Scheduler()
 {
     delete mFormat;
-    delete d;
 }
 
 void Scheduler::setShowDialogs(bool enable)
@@ -168,7 +168,7 @@ void Scheduler::acceptRequest(const IncidenceBase::Ptr &incidenceBase,
         return;
     }
 
-    QString schedulingUid = incidence->uid();
+    const QString schedulingUid = incidence->uid();
     QString errorString;
     Result result = ResultSuccess;
 
@@ -335,7 +335,7 @@ void Scheduler::acceptCancel(const IncidenceBase::Ptr &incidenceBase,
                                  << existingIncidences.count() << " incidences with schedulingID " << incidence->schedulingID();
 
     Result result = ResultIncidenceToDeleteNotFound;
-    QString errorString = i18n("Could not find incidence to delete.");
+    const QString errorString = i18n("Could not find incidence to delete.");
     for (const KCalendarCore::Incidence::Ptr &existingIncidence : existingIncidences) {
         qCDebug(AKONADICALENDAR_LOG) << "Considering this found event (" << (existingIncidence->isReadOnly() ? "readonly" : "readwrite")
                                      << ") :" << mFormat->toString(existingIncidence);
@@ -472,7 +472,7 @@ void Scheduler::acceptReply(const IncidenceBase::Ptr &incidenceBase,
         incidence->setAttendees(attendeesEv);
 
         bool attendeeAdded = false;
-        for (const auto &attNew : qAsConst(attendeesNew)) {
+        for (const auto &attNew : std::as_const(attendeesNew)) {
             QString msg = i18nc("@info", "%1 wants to attend %2 but was not invited.", attNew.fullName(), incidence->summary());
             if (!attNew.delegator().isEmpty()) {
                 msg = i18nc("@info", "%1 wants to attend %2 on behalf of %3.", attNew.fullName(), incidence->summary(), attNew.delegator());
