@@ -14,6 +14,8 @@
 #include <QObject>
 #include <QString>
 
+#include <memory>
+
 namespace KCalendarCore
 {
 class ICalFormat;
@@ -22,6 +24,8 @@ class FreeBusyCache;
 
 namespace Akonadi
 {
+class SchedulerPrivate;
+
 /**
   This class provides an encapsulation of iTIP transactions (RFC 2446).
   It is an abstract base class for inheritance by implementations of the
@@ -51,7 +55,7 @@ public:
       Creates a scheduler for calendar specified as argument.
     */
     explicit Scheduler(QObject *parent = nullptr);
-    ~Scheduler();
+    ~Scheduler() override;
 
     void setShowDialogs(bool enable);
 
@@ -77,7 +81,7 @@ public:
 
       @param incidence the incidence for the transaction. Must be valid.
       @param method the iTIP transaction method to use.
-      @param recipients the receipients of the transaction.
+      @param recipients the recipients of the transaction.
     */
     virtual void performTransaction(const KCalendarCore::IncidenceBase::Ptr &incidence, KCalendarCore::iTIPMethod method, const QString &recipients) = 0;
 
@@ -159,8 +163,7 @@ private Q_SLOTS:
 private:
     void connectCalendar(const Akonadi::CalendarBase::Ptr &calendar);
     Q_DISABLE_COPY(Scheduler)
-    struct Private;
-    Private *const d;
+    std::unique_ptr<SchedulerPrivate> const d;
 };
 }
 
