@@ -8,7 +8,7 @@
 
 #include "standardcalendaractionmanager.h"
 
-#include <entitytreemodel.h>
+#include <Akonadi/EntityTreeModel>
 
 #include <KActionCollection>
 #include <KCalendarCore/Event>
@@ -20,14 +20,12 @@
 
 using namespace Akonadi;
 
-class Q_DECL_HIDDEN StandardCalendarActionManager::Private
+class Akonadi::StandardCalendarActionManagerPrivate
 {
 public:
-    Private(KActionCollection *actionCollection, QWidget *parentWidget, StandardCalendarActionManager *parent)
+    StandardCalendarActionManagerPrivate(KActionCollection *actionCollection, QWidget *parentWidget, StandardCalendarActionManager *parent)
         : mActionCollection(actionCollection)
         , mParentWidget(parentWidget)
-        , mCollectionSelectionModel(nullptr)
-        , mItemSelectionModel(nullptr)
         , mParent(parent)
     {
         mGenericManager = new StandardActionManager(actionCollection, parentWidget);
@@ -36,7 +34,7 @@ public:
         mGenericManager->setCapabilityFilter(QStringList() << QStringLiteral("Resource"));
     }
 
-    ~Private()
+    ~StandardCalendarActionManagerPrivate()
     {
         delete mGenericManager;
     }
@@ -474,14 +472,11 @@ public:
 
 Akonadi::StandardCalendarActionManager::StandardCalendarActionManager(KActionCollection *actionCollection, QWidget *parent)
     : QObject(parent)
-    , d(new Private(actionCollection, parent, this))
+    , d(new StandardCalendarActionManagerPrivate(actionCollection, parent, this))
 {
 }
 
-StandardCalendarActionManager::~StandardCalendarActionManager()
-{
-    delete d;
-}
+StandardCalendarActionManager::~StandardCalendarActionManager() = default;
 
 void StandardCalendarActionManager::setCollectionSelectionModel(QItemSelectionModel *selectionModel)
 {
