@@ -9,17 +9,17 @@
 #include "todopurger_p.h"
 #include "utils_p.h"
 
-#include <kcalendarcore/todo.h>
+#include <KCalendarCore/Todo>
 
 #include <KLocalizedString>
 using namespace Akonadi;
 
-TodoPurger::Private::Private(TodoPurger *q)
+TodoPurgerPrivate::TodoPurgerPrivate(TodoPurger *q)
     : q(q)
 {
 }
 
-void TodoPurger::Private::onCalendarLoaded(bool success, const QString &message)
+void TodoPurgerPrivate::onCalendarLoaded(bool success, const QString &message)
 {
     if (success) {
         deleteTodos();
@@ -32,7 +32,7 @@ void TodoPurger::Private::onCalendarLoaded(bool success, const QString &message)
     }
 }
 
-void TodoPurger::Private::onItemsDeleted(int changeId, const QVector<Item::Id> &deletedItems, IncidenceChanger::ResultCode result, const QString &message)
+void TodoPurgerPrivate::onItemsDeleted(int changeId, const QVector<Item::Id> &deletedItems, IncidenceChanger::ResultCode result, const QString &message)
 {
     if (changeId != m_currentChangeId) {
         return; // Not ours.
@@ -45,7 +45,7 @@ void TodoPurger::Private::onItemsDeleted(int changeId, const QVector<Item::Id> &
     Q_EMIT q->todosPurged(result == IncidenceChanger::ResultCodeSuccess, deletedItems.count(), m_ignoredItems);
 }
 
-void TodoPurger::Private::deleteTodos()
+void TodoPurgerPrivate::deleteTodos()
 {
     if (!m_changer) {
         q->setIncidenceChager(new IncidenceChanger(this));
@@ -92,7 +92,7 @@ void TodoPurger::Private::deleteTodos()
     m_changer->setGroupwareCommunication(oldGroupware);
 }
 
-bool TodoPurger::Private::treeIsDeletable(const KCalendarCore::Todo::Ptr &todo)
+bool TodoPurgerPrivate::treeIsDeletable(const KCalendarCore::Todo::Ptr &todo)
 {
     Q_ASSERT(todo);
 
@@ -100,12 +100,12 @@ bool TodoPurger::Private::treeIsDeletable(const KCalendarCore::Todo::Ptr &todo)
         return false;
     }
 
-    const KCalendarCore::Incidence::List childs = m_calendar->childIncidences(todo->uid());
-    if (childs.isEmpty()) {
+    const KCalendarCore::Incidence::List children = m_calendar->childIncidences(todo->uid());
+    if (children.isEmpty()) {
         return true;
     }
 
-    for (const KCalendarCore::Incidence::Ptr &child : childs) {
+    for (const KCalendarCore::Incidence::Ptr &child : children) {
         KCalendarCore::Todo::Ptr childTodo = child.dynamicCast<KCalendarCore::Todo>();
 
         if (!childTodo) {
@@ -122,21 +122,18 @@ bool TodoPurger::Private::treeIsDeletable(const KCalendarCore::Todo::Ptr &todo)
 
 TodoPurger::TodoPurger(QObject *parent)
     : QObject(parent)
-    , d(new Private(this))
+    , d(new TodoPurgerPrivate(this))
 {
 }
 
-TodoPurger::~TodoPurger()
-{
-    delete d;
-}
+TodoPurger::~TodoPurger() = default;
 
 void TodoPurger::setIncidenceChager(IncidenceChanger *changer)
 {
     d->m_changer = changer;
     d->m_currentChangeId = -1;
     if (changer) {
-        connect(changer, &IncidenceChanger::deleteFinished, d, &Private::onItemsDeleted);
+        connect(changer, &IncidenceChanger::deleteFinished, d.get(), &TodoPurgerPrivate::onItemsDeleted);
     }
 }
 
@@ -154,7 +151,9 @@ void TodoPurger::purgeCompletedTodos()
         d->deleteTodos();
     } else {
         d->m_calendar = FetchJobCalendar::Ptr(new FetchJobCalendar(this));
-        connect(d->m_calendar.data(), SIGNAL(loadFinished(bool, QString)), d, SLOT(onCalendarLoaded(bool, QString)));
+        // clang-format off
+        connect(d->m_calendar.data(), SIGNAL(loadFinished(bool,QString)), d.get(), SLOT(onCalendarLoaded(bool,QString)));
+        // clang-format on
     }
 }
 
