@@ -4,17 +4,19 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TODOPURGER_H
-#define TODOPURGER_H
+#pragma once
 
 #include "akonadi-calendar_export.h"
 #include "calendarbase.h"
 
 #include <QObject>
 
+#include <memory>
+
 namespace Akonadi
 {
 class IncidenceChanger;
+class TodoPurgerPrivate;
 
 /**
  * @short Class to delete completed to-dos.
@@ -27,7 +29,7 @@ class AKONADI_CALENDAR_EXPORT TodoPurger : public QObject
     Q_OBJECT
 public:
     explicit TodoPurger(QObject *parent = nullptr);
-    ~TodoPurger();
+    ~TodoPurger() override;
 
     /**
      * Sets an IncidenceChanger.
@@ -44,7 +46,7 @@ public:
     void setCalendar(const CalendarBase::Ptr &calendar);
 
     /**
-     * Deletes completed to-dos. A to-do with uncomplete children won't be deleted.
+     * Deletes completed to-dos. A to-do with incomplete children won't be deleted.
      * @see purgeCompletedTodos()
      */
     void purgeCompletedTodos();
@@ -60,14 +62,12 @@ Q_SIGNALS:
      * @param success    True if the operation could be completed. @see lastError()
      * @param numDeleted Number of to-dos that were deleted.
      * @param numIgnored Number of completed to-dos that weren't deleted because they are read-only
-     *                   or have uncomplete or read-only children.
+     *                   or have incomplete or read-only children.
      */
     void todosPurged(bool success, int numDeleted, int numIgnored);
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<TodoPurgerPrivate> const d;
 };
 }
 
-#endif
