@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TODOPURGER_P_H
-#define TODOPURGER_P_H
+#pragma once
 
 #include "incidencechanger.h"
 #include "todopurger.h"
@@ -17,11 +16,11 @@ namespace Akonadi
 {
 class IncidenceChanger;
 
-class Q_DECL_HIDDEN TodoPurger::Private : public QObject
+class TodoPurgerPrivate : public QObject
 {
     Q_OBJECT
 public:
-    Private(TodoPurger *q);
+    explicit TodoPurgerPrivate(TodoPurger *q);
     IncidenceChanger *m_changer = nullptr;
     QString m_lastError;
     CalendarBase::Ptr m_calendar;
@@ -41,4 +40,3 @@ private:
 };
 }
 
-#endif
