@@ -7,13 +7,13 @@
 
 #include "utils_p.h"
 #include "akonadicalendar_debug.h"
+#include <Akonadi/CollectionDialog>
 #include <KEMailSettings>
 #include <KEmailAddress>
-#include <collectiondialog.h>
+#include <KIdentityManagement/Utils>
+#include <KMime/HeaderParsing>
 #include <identity.h>
 #include <identitymanager.h>
-#include <kidentitymanagement/utils.h>
-#include <kmime/kmime_header_parsing.h>
 
 #include <QPointer>
 #include <QWidget>
@@ -57,7 +57,8 @@ QString Akonadi::CalendarUtils::fullName()
     // Quote the username as it might contain commas and other quotable chars.
     tusername = KEmailAddress::quoteNameIfNecessary(tusername);
 
-    QString tname, temail;
+    QString tname;
+    QString temail;
     // ignore the return value from extractEmailAddressAndName() because
     // it will always be false since tusername does not contain "@domain".
     KEmailAddress::extractEmailAddressAndName(tusername, temail, tname);
